@@ -31,7 +31,7 @@ class FieldKind(graphene.Enum):
     EMAIL = "email"
     SLUG = "slug"
     PHONE = "phone"
-    UUID = "phone"
+    UUID = "uuid"
     IP = "ip"
     URL = "url"
     FILE = "file"
@@ -71,6 +71,13 @@ def get_field_schema_slug(field):
     }
 
 
+@get_field_schema.register(models.UUIDField)
+def get_field_schema_uuid(field):
+    return {
+        "kind": FieldKind.UUID,
+    }
+
+
 @get_field_schema.register(models.URLField)
 def get_field_schema_url(field):
     return {
